[![Tests](https://github.com/carlpayne/hm-python/workflows/Tests/badge.svg)](https://github.com/carlpayne/hm-python/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/carlpayne/hm-python/branch/master/graph/badge.svg)](https://codecov.io/gh/carlpayne/hm-python)
[![PyPI](https://img.shields.io/pypi/v/hm-python.svg)](https://pypi.org/project/hm-python/)
# hm-python
